@@ -6,20 +6,6 @@
 # Authors : Sean Gillies <sgillies@frii.com>
 #           Julien Anguenot <ja@nuxeo.com>
 #
-# This program is free software; you can redistribute it and/or modify it
-# under the terms of the GNU General Public License as published by the Free
-# Software Foundation; either version 2 of the License, or (at your option)
-# any later version.
-#
-# This program is distributed in the hope that it will be useful, but WITHOUT
-# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
-# FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
-# details.
-#
-# You should have received a copy of the GNU General Public License along with
-# this program; if not, write to the Free Software Foundation, Inc., 59 Temple
-# Place, Suite 330, Boston, MA 02111-1307 USA
-#
 # Contact email: sgillies@frii.com
 # =============================================================================
 
@@ -177,6 +163,8 @@ class ServiceMetadata(object):
         # properties
         self.service = self._root.find('Service/Name').text
         self.title = self._root.find('Service/Title').text
+        self.abstract = self._root.find('Service/Abstract').text
+        self.link = self._root.find('Service/OnlineResource').attrib.get('{http://www.w3.org/1999/xlink}href', '')
         
         # operations []
         self.operations = []
@@ -193,7 +181,13 @@ class ServiceMetadata(object):
         top = self._root.find('Capability/Layer')
         for elem in self._root.findall('Capability/Layer/Layer'):
             self.contents.append(ContentMetadata(elem, top))
-         
+
+        # keywords
+        self.keywords = [f.text for f in self._root.findall('Service/KeywordList/Keyword')]
+        
+        # contact person
+        self.provider = ContactMetadata(self._root.find('Service/ContactInformation'))
+        
     def getContentByName(self, name):
         """Return a named content item."""
         for item in self.contents:
@@ -279,7 +273,26 @@ class OperationMetadata:
             url = verb.find('OnlineResource').attrib['{http://www.w3.org/1999/xlink}href']
             methods.append((verb.tag, {'url': url}))
         self.methods = dict(methods)
-       
+
+
+class ContactMetadata:
+    """Abstraction for contact details advertised in GetCapabilities.
+    """
+
+    def __init__(self, elem):
+        self.name = elem.find('ContactPersonPrimary/ContactPerson').text
+        self.organization = elem.find('ContactPersonPrimary/ContactOrganization').text
+        address = elem.find('ContactAddress')
+        if address is not None:
+            try:    
+                self.address = address.find('Address').text
+                self.city = address.find('City').text
+                self.region = address.find('StateOrProvince').text
+                self.postcode = address.find('Postcode').text
+                self.country = address.find('Country').text
+            except: pass
+        self.email = elem.find('ContactElectronicMailAddress').text 
+
 
 # Deprecated classes follow
 # TODO: remove
